==> maineetloire_20170129_0405.tgz: var/www/vhosts/mag.maine-et-loire.fr/htdocs/wp-content/themes/emag_new/single.php <==
<?php get_header(); ?>

<?php
$colors_category = get_option("category_colors");
$active_color = $colors_category[the_category_ID(false)];

// Position sidebar
$position_sidebar = get_field("position_sidebar");
if ($position_sidebar == "Droite") {
    $css_sidebar = "aside.sidebar{right:0!important;left:inherit;}";
    $css_sidebar.="article.post-content{left:0 !important;right:inherit; width:60%;}";
    $css_sidebar.="aside.sidebar .container-widget .border-active{border-left:0; border-right:solid 6px;}";
    ?>
    <style>
        .sidebar .scrollers_sidebar {
            position: fixed;
            right: -30px;
            left:auto!important;
            top: 50%;
            transition-duration: 500ms;
            transition-property: all;
        }
        .sidebar .scrollers_sidebar a.back_sidebar, .sidebar .scrollers_sidebar a.forward_sidebar {
            display: block;
            width: 60px;
            height: 30px;
            background-image: url('http://digitalheroes.agence-ultramedia.com/wp-content/themes/emag_new/img/set_icons.png');
            background-repeat: no-repeat;
            background-size: 690px 480px;
            image-rendering: optimizeSpeed;
            image-rendering: pixellated;
            image-rendering: -o-crisp-edges;
            image-rendering: -webkit-optimize-contrast;
            image-rendering: optimize-contrast;
            -ms-interpolation-mode: nearest-neighbor;
            padding: 0;
            margin: 0;
            border: none;
            background-color: rgba(255,255,255,.85);
            text-indent: -9999px;
        }
        .sidebar .scrollers_sidebar a.back_sidebar {
            background-position: -180px -300px;
        }
        .sidebar .scrollers_sidebar a.back_sidebar:hover {
            background-position: -180px -330px;
            background-color: #fff;
        }
        .sidebar .scrollers_sidebar a.forward_sidebar {
            background-position: -120px -300px;
        }
        .sidebar .scrollers_sidebar a.forward_sidebar:hover {
            background-position: -120px -330px;
            background-color: #fff;
        }
    </style>
    <script>
        jQuery(document).ready(function ($) {
            $('.scrollers_sidebar').hover(function () {
                $(this).css('right', 0);
            }, function () {
                $(this).css('right', '-30px');
            });

            //Scroll top
            $('.back_sidebar').click(function () {
                $('.sidebar').animate({scrollTop: '-=500px'}, 500);
            });

            //Scroll bottom
            $('.forward_sidebar').click(function () {
                $('.sidebar').animate({scrollTop: '+=500px'}, 500);
            });
        });
    </script>
    <?php
} else {
    ?>
    <style>
        .sidebar .scrollers_sidebar {
            position: fixed;
            left: -30px;
            top: 50%;
            transition-duration: 500ms;
            transition-property: all;
        }
        .sidebar .scrollers_sidebar a.back_sidebar, .sidebar .scrollers_sidebar a.forward_sidebar {
            display: block;
            width: 60px;
            height: 30px;
            background-image: url('http://digitalheroes.agence-ultramedia.com/wp-content/themes/emag_new/img/set_icons.png');
            background-repeat: no-repeat;
            background-size: 690px 480px;
            image-rendering: optimizeSpeed;
            image-rendering: pixellated;
            image-rendering: -o-crisp-edges;
            image-rendering: -webkit-optimize-contrast;
            image-rendering: optimize-contrast;
            -ms-interpolation-mode: nearest-neighbor;
            padding: 0;
            margin: 0;
            border: none;
            background-color: rgba(255,255,255,.85);
            text-indent: -9999px;
        }
        .sidebar .scrollers_sidebar a.back_sidebar {
            background-position: -180px -300px;
        }
        .sidebar .scrollers_sidebar a.back_sidebar:hover {
            background-position: -180px -330px;
            background-color: #fff;
        }
        .sidebar .scrollers_sidebar a.forward_sidebar {
            background-position: -120px -300px;
        }
        .sidebar .scrollers_sidebar a.forward_sidebar:hover {
            background-position: -120px -330px;
            background-color: #fff;
        }
    </style>
    <script>
        jQuery(document).ready(function ($) {
            $('.scrollers_sidebar').hover(function () {
                $(this).css('left', 0);
            }, function () {
                $(this).css('left', '-30px');
            });

            //Scroll top
            $('.back_sidebar').click(function () {
                $('.sidebar').animate({scrollTop: '-=500px'}, 500);
            });

            //Scroll bottom
            $('.forward_sidebar').click(function () {
                $('.sidebar').animate({scrollTop: '+=500px'}, 500);
            });
        });
    </script>
    <?php
}
if ($position_sidebar == "Désactivé") {
    $css_sidebar = "aside.sidebar{display:none;}";
    $css_sidebar.="article.post-content{left:0 !important; width:100%;}";
}

// Active color
$rbg_active_color = dh_hex2rgb($active_color);
$light = "background-color:rgba(" . $rbg_active_color[0] . ", " . $rbg_active_color[1] . ", " . $rbg_active_color[2] . ", .15) !important";
$dark = "color:rgba(" . $rbg_active_color[0] . ", " . $rbg_active_color[1] . ", " . $rbg_active_color[2] . ", .9) !important";
?>

<style>
    .category_color, .bg-color-active{
        background-color:<?php echo $active_color; ?> !important;
    }
    .border-active{
        border-color: <?php echo $active_color; ?> !important;
    }
    .font-color-category, .title-widget{
        color:<?php echo $active_color; ?> !important;
    }
    .light{
        <?php echo $light; ?>
    }
    <?php echo $css_sidebar; ?>
</style>


<main role="main">
    <!-- section -->
    <section class="article-content">

        <aside class="sidebar" role="complementary">
            <?php
            if (has_post_thumbnail()) {
                $url_thumb = get_the_post_thumbnail_url();
                $title = get_post(get_post_thumbnail_id())->post_title;
		$legende = get_post(get_post_thumbnail_id())->post_excerpt;
                echo '<a href="' . $url_thumb . '" class="fancybox-button" rel="single-thumb" alt="' . $title . ' (pop-up)" title="' . $title . ' (pop-up)">';
                echo get_the_post_thumbnail($recent, 'full', array('title' => get_the_title()));
                echo '<span class="legende_img_une">' . $legende . '</span>';
                echo "</a>";
            }
            ?>
            <?php if (!function_exists('dynamic_sidebar') || !dynamic_sidebar('widget-area-1')) : endif; ?>
            <div class="scrollers_sidebar">
                <a class="back_sidebar" href="#">Retour</a>
                <a class="forward_sidebar" href="#">En avant</a>
            </div>
        </aside>
        <?php //if (have_posts()): while (have_posts()) : the_post(); ?>

        <!-- article -->
        <article class="post-content" id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
            <div class="post-wrapper">
                <?php
                // Sous-titre
                $sub_title = get_field("sous-titre");
                if (isset($sub_title))
                    echo '<h2 itemprop="name" class="font-color-category sub-title">' . $sub_title . "</h2>";
                ?>

                <h1 class="post-title"><?php the_title(); ?></h1>

                <?php
                // Chapo
                $chapo = get_field("chapo_de_larticle");
                if (isset($chapo)) {
                    echo "<div class='post-chapo'><p>" . $chapo . "</p></div>";
                }
                wp_reset_query();
                ?>
                <div>
                <?php
                the_content();
                ?>
                </div>
                <?php
                $postID = get_post();
                $links = get_field("amorce", $postID->ID);
                if (!empty($links)) {
                    ?>
                    <div class="amorce-cont">
                        <?php
                        foreach ($links as $link) {
                            ?>
                            <div class="post-link-out">
                                <a href="<?php echo $link['url_amorce']; ?>" target="_blank">
                                    <span class="icone-en-savoir-plus"></span>
                                    <span class="txt_amorce">
                                        <?php
                                        if ($link['titre_amorce']) {
                                            echo $link['titre_amorce'];
                                        } else {
                                            ?>En savoir plus<?php
                                        }
                                        ?>
                                    </span>
                                </a>
                            </div>
                            <?php
                        }
                        ?>
                    </div>
                    <?php
                }
                ?>

                <?php
                // Get Arbo
                $tree_menu = dh_get_tree_menu_nav();
                $id_item = get_the_ID(false);

                // Set link
                if (!empty($tree_menu)) {
                    $key = dh_find_key_array_by_value($tree_menu, $id_item);
                    $max = count($tree_menu);

                    $prev = $key - 1;
                    if ($prev < 0) {
                        $prev = $max - 1;
                    }

                    $next = $key + 1;
                    if ($next > ($max - 1)) {
                        $next = 0;
                    }

                    $link_prev = $tree_menu[$prev];
                    $link_current = $tree_menu[$key];
                    $link_next = $tree_menu[$next];
                }
                ?>

                <div class="contextual_nav" style="margin: 25px 0 0;">
                    <div class="previous">
                        <?php
                        if (!empty($link_prev['name'])) {
                            ?><a href="<?php echo $link_prev['url']; ?>" id="prev" title="<?php echo $link_prev['name']; ?>" alt="<?php echo $link_prev['name']; ?>"><span class='inner'><span class='text'><?php echo $link_prev['name']; ?></span><span class='icon'></span></a>
                        <?php } ?>
                    </div>
                    <div class="next">
                        <?php
                        if (!empty($link_next['name'])) {
                            ?><a href="<?php echo $link_next['url']; ?>" id="next" title="<?php echo $link_next['name']; ?>" alt="<?php echo $link_next['name']; ?>"><span class='inner'><span class='text'><?php echo $link_next['name']; ?></span><span class='icon'></span></a>
                        <?php } ?>
                    </div>
                </div>

                <?php
                $cat_colors = get_option('category_colors');
                $articles_en_relation = get_field("articles_en_relation");
                if ($articles_en_relation) {
                    ?>
                    <div class="related-articles">
                        <h4>À lire aussi</h4>
                        <div class="inner">
                            <?php
                            foreach ($articles_en_relation as $article_en_relation) {
                                $thumb = get_the_post_thumbnail($article_en_relation, 'thumbnail');
                                $link = get_permalink($article_en_relation);
                                $category = get_the_category($article_en_relation);
                                $id_cat = (int) $category[0]->cat_ID;
                                $lib_cat = (!empty($category[0]->name)) ? $category[0]->name : "";
                                $cat_colors_css = ($id_cat != 0) ? "color:" . $cat_colors[$id_cat] . ";" : "";
                                ?>
                                <div class="related-article">
                                    <a href="<?php echo $link; ?>">
                                        <?php if ($thumb) { ?>
                                            <figure class="related-image">
                                                <?php echo $thumb; ?>
                                            </figure>
                                        <?php } ?>
                                        <div class="related-text">
                                            <p class="parent" style="<?php echo $cat_colors_css; ?>"><?php echo $lib_cat; ?></p>
                                            <h5><?php echo dh_filtre_texte_bold($article_en_relation->post_title); ?></h5>
                                        </div>
                                    </a>
                                </div>
                            <?php } ?>
                        </div></div>
                    <?php
                }

                /*
                  $original_query = $wp_query;
                  $wp_query = null;
                  $args=array('posts_per_page'=> 6, 'tag' => $brand_name);
                  $wp_query = new WP_Query( $args );
                  if ( have_posts() ) :
                  while (have_posts()) : the_post();
                  echo '<li>';
                  the_title();
                  echo '</li>';
                  endwhile;
                  endif;
                  $wp_query = null;
                  $wp_query = $original_query;
                  wp_reset_postdata();
                 */
                ?>

                <p><?php //_e( 'Categorised in: ', 'html5blank' ); the_category(', '); // Separated by commas     ?></p>

                <br /><br />


                <?php
                if (is_user_logged_in()) {
                    ?>
                    <div class="edit-post-edito">
                        <i class="glyphicon glyphicon-pencil"></i>
                        <?php edit_post_link(); ?>
                    </div>
                <?php } ?>

                <div style="clear:both"></div>
                <?php comments_template(); ?>
            </div>
        </article>
        <!-- /article -->

        <?php //endwhile;  ?>

        <?php //else:   ?>

        <div style="clear:both"></div>

        <?php //endif;   ?>
    </section>
    <!-- /section -->

</main>
<?php get_footer(); ?>

==> maineetloire_20170205_0405.tgz: var/www/vhosts/mag.maine-et-loire.fr/htdocs/wp-content/themes/emag_new/single.php <==
<?php get_header(); ?>

<?php
$colors_category = get_option("category_colors");
$active_color = $colors_category[the_category_ID(false)];

// Position sidebar
$position_sidebar = get_field("position_sidebar");
if ($position_sidebar == "Droite") {
    $css_sidebar = "aside.sidebar{right:0!important;left:inherit;}";
    $css_sidebar.="article.post-content{left:0 !important;right:inherit; width:60%;}";
    $css_sidebar.="aside.sidebar .container-widget .border-active{border-left:0; border-right:solid 6px;}";
    ?>
    <style>
        .sidebar .scrollers_sidebar {
            position: fixed;
            right: -30px;
            left:auto!important;
            top: 50%;
            transition-duration: 500ms;
            transition-property: all;
        }
        .sidebar .scrollers_sidebar a.back_sidebar, .sidebar .scrollers_sidebar a.forward_sidebar {
            display: block;
            width: 60px;
            height: 30px;
            background-image: url('http://digitalheroes.agence-ultramedia.com/wp-content/themes/emag_new/img/set_icons.png');
            background-repeat: no-repeat;
            background-size: 690px 480px;
            image-rendering: optimizeSpeed;
            image-rendering: pixellated;
            image-rendering: -o-crisp-edges;
            image-rendering: -webkit-optimize-contrast;
            image-rendering: optimize-contrast;
            -ms-interpolation-mode: nearest-neighbor;
            padding: 0;
            margin: 0;
            border: none;
            background-color: rgba(255,255,255,.85);
            text-indent: -9999px;
        }
        .sidebar .scrollers_sidebar a.back_sidebar {
            background-position: -180px -300px;
        }
        .sidebar .scrollers_sidebar a.back_sidebar:hover {
            background-position: -180px -330px;
            background-color: #fff;
        }
        .sidebar .scrollers_sidebar a.forward_sidebar {
            background-position: -120px -300px;
        }
        .sidebar .scrollers_sidebar a.forward_sidebar:hover {
            background-position: -120px -330px;
            background-color: #fff;
        }
    </style>
    <script>
        jQuery(document).ready(function ($) {
            $('.scrollers_sidebar').hover(function () {
                $(this).css('right', 0);
            }, function () {
                $(this).css('right', '-30px');
            });

            //Scroll top
            $('.back_sidebar').click(function () {
                $('.sidebar').animate({scrollTop: '-=500px'}, 500);
            });

            //Scroll bottom
            $('.forward_sidebar').click(function () {
                $('.sidebar').animate({scrollTop: '+=500px'}, 500);
            });

        });

     
    });
    </script> 



    <?php
} else {
    ?>
    <style>
        .sidebar .scrollers_sidebar {
            position: fixed;
            left: -30px;
            top: 50%;
            transition-duration: 500ms;
            transition-property: all;
        }
        .sidebar .scrollers_sidebar a.back_sidebar, .sidebar .scrollers_sidebar a.forward_sidebar {
            display: block;
            width: 60px;
            height: 30px;
            background-image: url('http://digitalheroes.agence-ultramedia.com/wp-content/themes/emag_new/img/set_icons.png');
            background-repeat: no-repeat;
            background-size: 690px 480px;
            image-rendering: optimizeSpeed;
            image-rendering: pixellated;
            image-rendering: -o-crisp-edges;
            image-rendering: -webkit-optimize-contrast;
            image-rendering: optimize-contrast;
            -ms-interpolation-mode: nearest-neighbor;
            padding: 0;
            margin: 0;
            border: none;
            background-color: rgba(255,255,255,.85);
            text-indent: -9999px;
        }
        .sidebar .scrollers_sidebar a.back_sidebar {
            background-position: -180px -300px;
        }
        .sidebar .scrollers_sidebar a.back_sidebar:hover {
            background-position: -180px -330px;
            background-color: #fff;
        }
        .sidebar .scrollers_sidebar a.forward_sidebar {
            background-position: -120px -300px;
        }
        .sidebar .scrollers_sidebar a.forward_sidebar:hover {
            background-position: -120px -330px;
            background-color: #fff;
        }
    </style>
    <script>
        jQuery(document).ready(function ($) {
            $('.scrollers_sidebar').hover(function () {
                $(this).css('left', 0);
            }, function () {
                $(this).css('left', '-30px');
            });

            //Scroll top
            $('.back_sidebar').click(function () {
                $('.sidebar').animate({scrollTop: '-=500px'}, 500);
            });

            //Scroll bottom
            $('.forward_sidebar').click(function () {
                $('.sidebar').animate({scrollTop: '+=500px'}, 500);
            });
        });
    </script>
    <?php
}
if ($position_sidebar == "Désactivé") {
    $css_sidebar = "aside.sidebar{display:none;}";
    $css_sidebar.="article.post-content{left:0 !important; width:100%;}";
}

// Active color
$rbg_active_color = dh_hex2rgb($active_color);
$light = "background-color:rgba(" . $rbg_active_color[0] . ", " . $rbg_active_color[1] . ", " . $rbg_active_color[2] . ", .15) !important";
$dark = "color:rgba(" . $rbg_active_color[0] . ", " . $rbg_active_color[1] . ", " . $rbg_active_color[2] . ", .9) !important";
?>

<style>
    .category_color, .bg-color-active{
        background-color:<?php echo $active_color; ?> !important;
    }
    .border-active{
        border-color: <?php echo $active_color; ?> !important;
    }
    .font-color-category, .title-widget{
        color:<?php echo $active_color; ?> !important;
    }
    .light{
        <?php echo $light; ?>
    }
    <?php echo $css_sidebar; ?>
</style>


<main role="main">
    <!-- section -->
    <section class="article-content">

        <aside class="sidebar" role="complementary">
	  <div class="hoverimg">
            <?php
            if (has_post_thumbnail()) {
                $url_thumb = get_the_post_thumbnail_url();
                $title = get_post(get_post_thumbnail_id())->post_title;
		$legende = get_post(get_post_thumbnail_id())->post_excerpt;
		$image_alt = get_post_meta( $image->id, '_wp_attachment_image_alt', true);

                /*echo '<a href="' . $url_thumb . '" class="fancybox-button" rel="single-thumb" alt="' . $title . ' (pop-up)" title="' . $title . ' (pop-up)">';*/
		echo '<a href="' . $url_thumb . '" class="fancybox-button" rel="single-thumb" alt="' . $image_alt . '" title="' . $legende . '">';
                echo get_the_post_thumbnail($recent, 'full', array('title' => $legende));
		if($legende==""){
		echo '<span style="display:none;" class="legende_img_une">' . $legende . '</span>';
				}else{
                echo '<span class="legende_img_une">' . $legende . '</span>';
			}
                echo "</a>";
            }
            ?>
           </div>
            <?php if (!function_exists('dynamic_sidebar') || !dynamic_sidebar('widget-area-1')) : endif; ?>
            <div class="scrollers_sidebar">
                <a class="back_sidebar" href="#">Retour</a>
                <a class="forward_sidebar" href="#">En avant</a>
            </div>
        </aside>
        <?php //if (have_posts()): while (have_posts()) : the_post(); ?>

        <!-- article -->
        <article class="post-content" id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
            <div class="post-wrapper">
                <?php
                // Sous-titre
                $sub_title = get_field("sous-titre");
                if (isset($sub_title))
                    echo '<h2 itemprop="name" class="font-color-category sub-title">' . $sub_title . "</h2>";
                ?>

                <h1 class="post-title"><?php the_title(); ?></h1>

                <?php
                // Chapo
                $chapo = get_field("chapo_de_larticle");
                if (isset($chapo)) {
                    echo "<div class='post-chapo'><p>" . $chapo . "</p></div>";
                }
                wp_reset_query();
                ?>
                <div>
                <?php
                the_content();
                ?>
                </div>
                <?php
                $postID = get_post();
                $links = get_field("amorce", $postID->ID);
                if (!empty($links)) {
                    ?>
                    <div class="amorce-cont">
                        <?php
                        foreach ($links as $link) {
                            ?>
                            <div class="post-link-out">
                                <a href="<?php echo $link['url_amorce']; ?>" target="_blank">
                                    <span class="icone-en-savoir-plus"></span>
                                    <span class="txt_amorce">
                                        <?php
                                        if ($link['titre_amorce']) {
                                            echo $link['titre_amorce'];
                                        } else {
                                            ?>En savoir plus<?php
                                        }
                                        ?>
                                    </span>
                                </a>
                            </div>
                            <?php
                        }
                        ?>
                    </div>
                    <?php
                }
                ?>

                <?php
                // Get Arbo
                $tree_menu = dh_get_tree_menu_nav();
                $id_item = get_the_ID(false);

                // Set link
                if (!empty($tree_menu)) {
                    $key = dh_find_key_array_by_value($tree_menu, $id_item);
                    $max = count($tree_menu);

                    $prev = $key - 1;
                    if ($prev < 0) {
                        $prev = $max - 1;
                    }

                    $next = $key + 1;
                    if ($next > ($max - 1)) {
                        $next = 0;
                    }

                    $link_prev = $tree_menu[$prev];
                    $link_current = $tree_menu[$key];
                    $link_next = $tree_menu[$next];
                }
                ?>

                <div class="contextual_nav" style="margin: 25px 0 0;">
                    <div class="previous">
                        <?php
                        if (!empty($link_prev['name'])) {
                            ?><a href="<?php echo $link_prev['url']; ?>" id="prev" title="<?php echo $link_prev['name']; ?>" alt="<?php echo $link_prev['name']; ?>"><span class='inner'><span class='text'><?php echo $link_prev['name']; ?></span><span class='icon'></span></a>
                        <?php } ?>
                    </div>
                    <div class="next">
                        <?php
                        if (!empty($link_next['name'])) {
                            ?><a href="<?php echo $link_next['url']; ?>" id="next" title="<?php echo $link_next['name']; ?>" alt="<?php echo $link_next['name']; ?>"><span class='inner'><span class='text'><?php echo $link_next['name']; ?></span><span class='icon'></span></a>
                        <?php } ?>
                    </div>
                </div>

                <?php
                $cat_colors = get_option('category_colors');
                $articles_en_relation = get_field("articles_en_relation");
                if ($articles_en_relation) {
                    ?>
                    <div class="related-articles">
                        <h4>À lire aussi</h4>
                        <div class="inner">
                            <?php
                            foreach ($articles_en_relation as $article_en_relation) {
                                $thumb = get_the_post_thumbnail($article_en_relation, 'thumbnail');
                                $link = get_permalink($article_en_relation);
                                $category = get_the_category($article_en_relation);
                                $id_cat = (int) $category[0]->cat_ID;
                                $lib_cat = (!empty($category[0]->name)) ? $category[0]->name : "";
                                $cat_colors_css = ($id_cat != 0) ? "color:" . $cat_colors[$id_cat] . ";" : "";
                                ?>
                                <div class="related-article">
                                    <a href="<?php echo $link; ?>">
                                        <?php if ($thumb) { ?>
                                            <figure class="related-image">
                                                <?php echo $thumb; ?>
                                            </figure>
                                        <?php } ?>
                                        <div class="related-text">
                                            <p class="parent" style="<?php echo $cat_colors_css; ?>"><?php echo $lib_cat; ?></p>
                                            <h5><?php echo dh_filtre_texte_bold($article_en_relation->post_title); ?></h5>
                                        </div>
                                    </a>
                                </div>
                            <?php } ?>
                        </div></div>
                    <?php
                }

                /*
                  $original_query = $wp_query;
                  $wp_query = null;
                  $args=array('posts_per_page'=> 6, 'tag' => $brand_name);
                  $wp_query = new WP_Query( $args );
                  if ( have_posts() ) :
                  while (have_posts()) : the_post();
                  echo '<li>';
                  the_title();
                  echo '</li>';
                  endwhile;
                  endif;
                  $wp_query = null;
                  $wp_query = $original_query;
                  wp_reset_postdata();
                 */
                ?>

                <p><?php //_e( 'Categorised in: ', 'html5blank' ); the_category(', '); // Separated by commas     ?></p>

                <br /><br />


                <?php
                if (is_user_logged_in()) {
                    ?>
                    <div class="edit-post-edito">
                        <i class="glyphicon glyphicon-pencil"></i>
                        <?php edit_post_link(); ?>
                    </div>
                <?php } ?>

                <div style="clear:both"></div>
                <?php comments_template(); ?>
            </div>
        </article>
        <!-- /article -->

        <?php //endwhile;  ?>

        <?php //else:   ?>

        <div style="clear:both"></div>

        <?php //endif;   ?>
    </section>
    <!-- /section -->

</main>


<?php get_footer(); ?>
